#ifdef GL_ES
	#define LOWP lowp
	precision mediump float;
#else
	#define LOWP 
#endif

uniform vec2 u_res;
uniform vec2 u_center;
uniform sampler2D u_texture;
uniform float time;
uniform float u_desaturate;

varying LOWP vec4 v_color;
varying LOWP float v_illumination;
varying LOWP float v_height;

const float distFactor = 0.2;

const float desatBlack = 0.12;

#define SepiaDesaturate(color) ((1.0 - desatBlack) * dot(color, vec3(0.299, 0.587, 0.114)) + desatBlack) * vec3(1.2, 1.0, 0.8)

void main()
{
	LOWP float theta = atan(gl_FragCoord.y - u_center.y, gl_FragCoord.x - u_center.x);
	LOWP vec2 point = gl_FragCoord.xy - vec2(cos(theta), sin(theta)) * v_height * length(gl_FragCoord.xy - u_center) * distFactor;

	LOWP vec4 sample = texture2D(u_texture, point / u_res);

	LOWP vec3 c = mix(
				v_color.rgb * sample.rgb * 2.0 * sample.a,	//lit
				v_color.rgb,								//raw
				v_illumination
			);

	LOWP vec3 sepia = SepiaDesaturate(c);

	gl_FragColor = vec4(mix(c, sepia, u_desaturate), 1.0);
}