#ifdef GL_ES
	#define LOWP lowp
	precision mediump float;
#else
	#define LOWP 
#endif

uniform vec2 u_res;
uniform vec2 u_center;
uniform sampler2D u_texture;
uniform float time;
uniform float u_desaturate;

varying LOWP vec4 v_color;
varying LOWP float v_illumination;
varying LOWP float v_height;

const float heightDistFactor = 0.2;
const float gradientRange = 1.0/4.0;
const float minGradient = 0.5 - gradientRange/2.0;
const float maxGradient = 0.5 + gradientRange/2.0;

const float desatBlack = 0.10;

#define Blend(base, blend, funcf) 		vec3(funcf(base.r, blend.r), funcf(base.g, blend.g), funcf(base.b, blend.b))
#define BlendSoftLightf(base, blend) ((blend < 0.5) ? (2.0 * base * blend + base * base * (1.0 - 2.0 * blend)) : (sqrt(base) * (2.0 * blend - 1.0) + 2.0 * base * (1.0 - blend)))

void main()
{
	//Calculate light sample offset accordoing to height
	float theta = atan(gl_FragCoord.y - u_center.y, gl_FragCoord.x - u_center.x);
	vec2 point = gl_FragCoord.xy - vec2(cos(theta), sin(theta)) * v_height * length(gl_FragCoord.xy - u_center) * heightDistFactor;

	vec4 light = texture2D(u_texture, point / u_res);

	vec3 litColor = mix(
				v_color.rgb * light.rgb * 2.0 * light.a,	//lit
				v_color.rgb,								//raw
				v_illumination
			);


	float gradientVal = clamp(1.0 - length(gl_FragCoord.xy - (u_center + vec2(0.0, 100.0))) / 300.0, 0.0, 1.0) * (maxGradient - minGradient) + minGradient;

	vec3 c = Blend(litColor, vec3(gradientVal), BlendSoftLightf);

	// Convert to greyscale using NTSC weightings and raised black point
	float grey = (1.0 - desatBlack) * dot(c, vec3(0.299, 0.587, 0.114)) + desatBlack;

	// Play with these rgb weightings to get different tones.
	// (As long as all rgb weightings add up to 1.0 you won't lighten or darken the image)
	vec3 sepia = grey * vec3(1.2, 1.0, 0.8);

	vec3 final = mix(c, sepia, u_desaturate);

	gl_FragColor = vec4(final, 1.0);
}